﻿* Encoding: UTF-8.
/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIÓN DE LA EDUCACIÓN
/*             UNIDAD DE EVALUACIÓN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIÓN GENERAL DE MEDICIÓN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIÓN DE TRATAMIENTO DE DATOS
/*
/*___________________________________________________________________________
/*
/*                            EVOE-ECEA
/*                            PREESCOLAR
/*
/*                   **** PADRES DE FAMILIA ****
/*
/*_____________________________________________________________________________
/*
/*
/*     SINTAXIS PARA ETIQUETAR LA TABLA DE DATOS DE PADRES DE FAMILIA
/*                  EN FORMATO SPSS PARA ECEA00, 2017
/*_____________________________________________________________________________
/*
/*  La sintaxis etiqueta las variables así como sus valores y declara los
/*  valores perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para etiquetar la base de datos (tabla de datos) es necesario:
/*      1) Abrir la tabla de en formato SPSS y el archivo de sintaxis
/*      2) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar el ejecución del sintaxis, la tabla ECEA00_2017_Padres_Familia.SAV
/*  quedará etiquetada.
/*
/* CONTACTO:
/*
/*      Para mayor información o aclaración de dudas favor de contactar a la
/*      Dirección de Tratamiento de Datos
/*      Correo electrónico: analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San José Insurgentes
/*                 Del. Benito Juárez. Ciudad de México
/*
/* FECHA DE LIBERACIÓN:  5 de abril de 2019
/*
/*  ****************************************************************************/




/***********************************************************************
/* Etiquetas de variables
/*
/**********************************************************************.

VARIABLE LABELS
         NACIONAL               "Variable auxiliar para obtener promedios nacionales"
         FOL_PAD                "Identificador del padre"
         ESCUELA                "Identificador de la escuela"
         NIVEL                  "Nivel educativo"
         ID_ENT                 "Entidad federativa (identificador numérico)"
         NOM_ENT                "Entidad federativa"
         ID_TURNO               "Identificador numérico del turno escolar"
         TURNO                  "Turno de la escuela"
         ID_PREESTRATO          "Identificador numérico del preestrato"
         PREESTRATO             "Dominio de interés"
         W_FPARWT               "Peso muestral final del Padre de Familia"
         P01                    "¿Tiene hijas o hijos inscritos en primer grado de preescolar?"
         P02                    "¿Tiene hijas o hijos inscritos en segundo grado de preescolar?"
         P03                    "¿Tiene hijas o hijos inscritos en tercer grado de preescolar?"
         P04                    "Por lo general, ¿cómo se siente su hija o hijo en este preescolar?"
         P05                    "Por lo general, ¿qué tanto miedo siente su hija o hijo al venir a este preescolar?"
         P06                    "¿Qué tanto le gusta a su hija o hijo estar en este preescolar?"
         P07                    "En general, ¿cómo considera que es el trato de la maestra hacia su hija o hijo?"
         P08                    "En general, ¿la maestra apoya a su hija o hijo cuando lo necesita durante la jornada escolar?"
         P09                    "En general, ¿la maestra felicita o reconoce a su hija o hijo por las actividades que realiza?"
         P10                    "En general, ¿la maestra le da el mismo trato a su hija o hijo que al resto del grupo?"
         P11                    "En general, ¿cómo es el trato de la maestra de su hija o hijo hacia usted?"
         P12                    "En general, ¿cómo es el trato que la directora de este preescolar da a su hija o hijo?"
         P13                    "En general, ¿cómo es el trato que las otras maestras de este preescolar dan a su hija o hijo?"
         P14                    "¿Usted conoce las reglas, normas o los acuerdos que hay en el salón de clases de su hija o hijo?"
         P15                    "¿Usted conoce las reglas, normas o los acuerdos de la escuela, por ejemplo, el reglamento escolar?"
         P16                    "¿Cómo le dieron a conocer las reglas, normas o los acuerdos de la escuela, por ejemplo, el reglamento escolar?"
         P17                    "En general, ¿está de acuerdo con el contenido del reglamento escolar de este preescolar?"
         P18                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo le han suspendido un día o más como castigo en este preescolar?"
         P19                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo le han impedido la entrada a este preescolar por llegar tarde?"
         P20                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo le han impedido la entrada a este preescolar por no traer el uniforme o traerlo incompleto?"
         P21                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo le han impedido la entrada a este preescolar por su arreglo personal?"
         P22                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo le han impedido entrar a este preescolar por no dar la aportación económica?"
         P23                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo la maestra actual le ha gritado de forma agresiva para regañarle o llamarle la atención?"
         P24                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo la maestra actual le ha dejado sin recreo como castigo?"
         P25                    "Durante este ciclo escolar (2017-2018), ¿la maestra actual ha castigado a su hija o hijo dejándole sin comer, sin tomar agua o sin ir al baño durante la jornada escolar?"
         P26                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo la maestra actual le ha sacado del salón de clases por no traer el material o alguna tarea?"
         P27                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo la maestra actual le ha dado un pellizco, coscorrón, jalón de oreja, nalgada u otro golpe?"
         P28                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo la maestra actual le ha puesto un apodo o le ha dicho alguna palabra que lo ridiculice, haga sentir mal o incómodo?"
         P29                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo la maestra actual le ha dejado encerrado en algún lugar de la escuela como castigo?"
         P30                    "Durante este ciclo escolar (2017-2018), ¿a su hija o hijo la maestra actual le ha regañado o castigado por hablar su dialecto o lengua indígena?"
         P31                    "En este preescolar, ¿usted ha asistido a pláticas o talleres para padres de familia (escuela para padres, cursos o reuniones sobre cómo apoyar el aprendizaje o cómo tratar a su hija o hijo)?"
         P32a                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? La importancia de que mi hija o hijo asista al preescolar"
         P32b                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? Lo que va a aprender mi hija o hijo en preescolar"
         P32c                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? Las características y necesidades de niñas y niños en edad preescolar"
         P32d                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? Los avances de mi hija o hijo en sus aprendizajes"
         P32e                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? Los tipos de actividades que se desarrollan en el salón de clases"
         P32f                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? La forma de apoyar en casa el aprendizaje de mi hija o hijo"
         P32g                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? Los proyectos para mejorar el preescolar"
         P32h                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? Las formas en que los padres de familia pueden colaborar para el mantenimiento y funcionamiento del preescolar"
         P32i                   "En este preescolar, ¿sobre cuáles de los siguientes temas le han dado información? Otro tema"
         P33a                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Leer cuentos, historias, fábulas u otros"
         P33b                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Usar juegos de mesa como memorama, rompecabezas, dominó u otros"
         P33c                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Repasar actividades vistas en clase como escribir, contar, recortar, hacer experimentos u otras"
         P33d                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Realizar actividades como dibujar, pintar, cantar, bailar u otras"
         P33e                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Hacer actividades físicas como jugar a la pelota, saltar la cuerda, salir de paseo u otras"
         P33f                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Acudir a ferias, fiestas patronales u otros"
         P33g                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Asistir a eventos musicales, ir al cine, al museo u otros"
         P33h                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Practicar actividades de cuidado personal como peinarse, amarrarse las agujetas, vestirse u otras"
         P33i                   "En este preescolar, ¿cuáles de las siguientes actividades le han pedido que realice con su hija o hijo fuera del horario escolar? Otra actividad"
         P34                    "¿Cuánto tiempo hace de la casa de su hija o hijo al preescolar?"
         P35                    "¿Cuál es el principal medio de transporte por el cual llegan, usted y su hija o hijo, al preescolar?"
         P36                    "Aproximadamente, ¿cuánto dinero gasta al día en transporte para que su hija o hijo llegue y regrese del preescolar?"
         P37                    "Usted es:"
         P38                    "¿Cuántos años cumplidos tiene usted?"
         P39                    "¿Qué es usted de la niña o del niño por el que está contestando este cuestionario?"
         P40                    "¿Usted está a cargo del cuidado de la niña o del niño?"
         P41a                   "¿Cuáles de los familiares que viven con su hija o hijo hablan algún dialecto o lengua indígena? Madre"
         P41b                   "¿Cuáles de los familiares que viven con su hija o hijo hablan algún dialecto o lengua indígena? Padre"
         P41c                   "¿Cuáles de los familiares que viven con su hija o hijo hablan algún dialecto o lengua indígena? Hermana o hermano"
         P41d                   "¿Cuáles de los familiares que viven con su hija o hijo hablan algún dialecto o lengua indígena? Abuela o abuelo"
         P41e                   "¿Cuáles de los familiares que viven con su hija o hijo hablan algún dialecto o lengua indígena? Otro familiar"
         P42a                   "¿En qué lengua o lenguas aprendió a hablar su hija o hijo? Español"
         P42b                   "¿En qué lengua o lenguas aprendió a hablar su hija o hijo? Un dialecto o lengua indígena"
         P42c                   "¿En qué lengua o lenguas aprendió a hablar su hija o hijo? Otra lengua"
         P43                    "Por su cultura, ¿usted o algún otro de los familiares con los que vive su hija o hijo se considera indígena?"
         P44                    "De acuerdo con su cultura, historia y tradiciones, ¿usted o algún otro de los familiares con los que vive su hija o hijo se considera negro, es decir, afromexicano o afrodescendiente?"
         P45                    "Para contestar este cuestionario, ¿usted necesitó que alguien le leyera las preguntas?"
         P46                    "Para contestar este cuestionario, ¿usted necesitó que alguien le tradujera las preguntas a otro idioma?"
         WVARSTRR               "Identificador del pseudoestrato (1 a 100) definido para el cálculo de errores estándar con el método de remuestreo BRR"
         W_FPAR1                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR2                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR3                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR4                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR5                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR6                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR7                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR8                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR9                "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR10               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR11               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR12               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR13               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR14               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR15               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR16               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR17               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR18               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR19               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR20               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR21               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR22               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR23               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR24               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR25               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR26               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR27               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR28               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR29               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR30               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR31               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR32               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR33               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR34               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR35               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR36               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR37               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR38               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR39               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR40               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR41               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR42               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR43               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR44               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR45               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR46               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR47               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR48               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR49               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR50               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR51               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR52               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR53               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR54               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR55               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR56               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR57               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR58               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR59               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR60               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR61               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR62               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR63               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR64               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR65               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR66               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR67               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR68               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR69               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR70               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR71               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR72               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR73               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR74               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR75               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR76               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR77               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR78               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR79               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR80               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR81               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR82               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR83               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR84               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR85               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR86               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR87               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR88               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR89               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR90               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR91               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR92               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR93               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR94               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR95               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR96               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR97               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR98               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR99               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         W_FPAR100              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
         VERSION                "Versión de la base de datos"
.


/***********************************************************************
/*       Etiquetas de valores.
/*
/**********************************************************************.


VALUE LABELS
          ID_ENT
                               1      "Aguascalientes"
                               2      "Baja California"
                               3      "Baja California Sur"
                               4      "Campeche"
                               5      "Coahuila"
                               6      "Colima"
                               7      "Chiapas"
                               8      "Chihuahua"
                               9      "Ciudad de México"
                               10     "Durango"
                               11     "Guanajuato"
                               12     "Guerrero"
                               13     "Hidalgo"
                               14     "Jalisco"
                               15     "México"
                               16     "Michoacán"
                               17     "Morelos"
                               18     "Nayarit"
                               19     "Nuevo León"
                               20     "Oaxaca"
                               21     "Puebla"
                               22     "Querétaro"
                               23     "Quintana Roo"
                               24     "San Luis Potosí"
                               25     "Sinaloa"
                               26     "Sonora"
                               27     "Tabasco"
                               28     "Tamaulipas"
                               29     "Tlaxcala"
                               30     "Veracruz"
                               31     "Yucatán"
                               32     "Zacatecas"/
          ID_PREESTRATO
                               1       "Cursos Comunitarios"
                               2       "Gral Unidocente"
                               3       "Gral No Unidocente"
                               4       "Indígena Unidocente"
                               5       "Indígena No Unidocente"
                               6       "Privadas"/
          ID_TURNO
                               1      "Matutino"
                               2      "Vespertino"
                               3      "Nocturno"
                               4      "Discontinuo"
                               5      "Tiempo Completo"
                               6      "Complementario"
                               7      "Jornada Ampliada"
                               8      "Continuo"/
          P01
          P02
          P03                  1      "Sí"
                               2      "No"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P04                  1      "Muy contento(a)"
                               2      "Contento(a)"
                               3      "Triste"
                               4      "Muy triste"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P05                  1      "Mucho"
                               2      "Algo"
                               3      "Muy poco"
                               4      "Nada"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P06                  1      "Mucho"
                               2      "Poco"
                               3      "No le gusta"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P07                  1      "Buen trato: Lo respeta, lo escucha y lo atiende"
                               2      "Trato regular: No siempre lo respeta, lo escucha o lo atiende"
                               3      "Mal trato: No lo respeta, ni lo escucha, ni lo atiende"
                               4      "No sé"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P08
          P09
          P10                  1      "Sí"
                               2      "No"
                               3      "No sé"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P11                  1      "Me trata bien: Es respetuosa y está dispuesta a platicar conmigo sobre mi hija o hijo"
                               2      "El trato es regular: No siempre es respetuosa o está dispuesta a platicar conmigo sobre mi hija o hijo"
                               3      "Me trata mal: Es irrespetuosa y no está dispuesta a platicar conmigo sobre mi hija o hijo"
                               4      "No conozco a la maestra"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P12                  1      "Buen trato: Lo respeta, lo escucha y lo atiende"
                               2      "Trato regular: No siempre lo respeta, lo escucha o lo atiende"
                               3      "Mal trato: No lo respeta, ni lo escucha, ni lo atiende"
                               4      "No sé"
                               5      "No hay directora o es la misma maestra de mi hija o hijo"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P13                  1      "Buen trato: Lo respetan, lo escuchan y lo atienden"
                               2      "Trato regular: No siempre lo respetan, lo escuchan o lo atienden"
                               3      "Mal trato: No lo respetan, ni lo escuchan, ni lo atienden"
                               4      "No sé"
                               5      "No hay otras maestras en el preescolar"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P14
          P15                  1      "Sí"
                               2      "No"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P16                  1      "De forma oral"
                               2      "De forma escrita"
                               3      "Ambas, de forma oral y escrita"
                               4      "De ninguna forma: ni oral, ni escrita"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P17                  1      "Sí"
                               2      "No"
                               3      "No conozco el reglamento escolar"
                               4      "No hay reglamento escolar"
                               96     "Valor Inconsistente"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P18
          P19
          P20
          P21
          P22
          P23
          P24
          P25
          P26
          P27
          P28
          P29                  1      "Sí"
                               2      "No"
                               3      "No sé"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P30                  1      "Sí"
                               2      "No"
                               3      "No sé"
                               4      "Mi hija o hijo no habla dialecto o lengua indígena"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P31
          P32a
          P32b
          P32c
          P32d
          P32e
          P32f
          P32g
          P32h
          P32i
          P33a
          P33b
          P33c
          P33d
          P33e
          P33f
          P33g
          P33h
          P33i                 1      "Sí"
                               2      "No"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P34                  1      "Menos de 15 minutos"
                               2      "Entre 16 y 30 minutos"
                               3      "Entre 31 y 45 minutos"
                               4      "Entre 46 minutos y 1 hora"
                               5      "Más de 1 hora"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P35                  1      "A pie"
                               2      "Transporte público (camión, microbús, pesero, metro, tren u otro)"
                               3      "Taxi, bicitaxi, mototaxi"
                               4      "Vehículo u otro transporte particular (bicicleta, motocicleta, automóvil u otro)"
                               5      "Transporte escolar (servicio que ofrece la escuela, con o sin costo)"
                               6      "Otro tipo de transporte como caballo, carreta, lancha u otro"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P36                  1      "Menos de 15 pesos"
                               2      "Entre 16 y 30 pesos"
                               3      "Entre 31 y 45 pesos"
                               4      "Entre 46 y 60 pesos"
                               5      "Entre 61 y 75 pesos"
                               6      "Entre 76 y 90 pesos"
                               7      "Más de 90 pesos"
                               8      "Nada, no gasto dinero para llevarla(o) y regresarla(o)"
                               96     "Valor Inconsistente"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P37                  1      "hombre"
                               2      "mujer"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P38                  1      "Menos de 18"
                               2      "19 a 25"
                               3      "26 a 30"
                               4      "31 a 35"
                               5      "36 a 40"
                               6      "Más de 40"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P39                  1      "Soy su mamá"
                               2      "Soy su papá"
                               3      "Soy su hermana o hermano"
                               4      "Soy su abuela o abuelo"
                               5      "Otro"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P40
          P41a
          P41b
          P41c
          P41d
          P41e
          P42a
          P42b
          P42c                 1      "Sí"
                               2      "No"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P43                  1      "Sí"
                               2      "Sí, en parte"
                               3      "No"
                               4      "No sé"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P44                  1      "Sí"
                               2      "Sí, en parte"
                               3      "No"
                               4      "No sé"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
          P45
          P46                  1      "Sí"
                               2      "No"
                               98     "Respuesta Múltiple"
                               99     "Respuesta Omitida"/
.



/***********************************************************************
/* Declaración de valores Perdidos.
/*
/**********************************************************************.

MISSING VALUES P01 TO P16 (98,99).
MISSING VALUES P17 (96,98,99).
MISSING VALUES P18 TO P35 (98,99).
MISSING VALUES P36 (96,98,99).
MISSING VALUES P37 TO P46 (98,99).

EXECUTE .



